diff --git a/apps/basic_demos/app_single_cam/app_single_cam_main.c b/apps/basic_demos/app_single_cam/app_single_cam_main.c
index a295c78..ce57c78 100755
--- a/apps/basic_demos/app_single_cam/app_single_cam_main.c
+++ b/apps/basic_demos/app_single_cam/app_single_cam_main.c
@@ -76,6 +76,14 @@ static vx_uint8 num_sensors_found;
 static IssSensor_CreateParams sensorParams;
 
 #define NUM_CAPT_CHANNELS   (4u)
+/** \brief Flip Type is None */
+#define FLIP_TYPE_NONE                   ((uint32_t) 0x00U)
+/** \brief Flip Type is Horizontal i.e. along Y axis */
+#define FLIP_TYPE_H                      ((uint32_t) 0x01U)
+/** \brief Flip Type is Vertical i.e. along X axis */
+#define FLIP_TYPE_V                      ((uint32_t) 0x02U)
+/** \brief Flip Type is Horizontal + Vertical */
+#define FLIP_TYPE_HV                     ((uint32_t) 0x03U)
 
 #ifdef _APP_DEBUG_
 static char *app_get_test_file_path()
@@ -1201,6 +1209,30 @@ static char menu[] = {
     "\n"
 #endif
 #endif
+    "\n f: Flip Image"
+    "\n"
+    "\n x: Exit"
+    "\n"
+    "\n Enter Choice: "
+};
+
+static char flipMenu[] = {
+    "\n"
+    "\n =========================="
+    "\n Select the flip option"
+    "\n =========================="
+    "\n"
+    "\n v: Vertical Flip"
+    "\n"
+    "\n"
+    "\n h: Horizontal Flip"
+    "\n"
+    "\n"
+    "\n f: Full Flip"
+    "\n"
+    "\n"
+    "\n n: No Flip"
+    "\n"
     "\n x: Exit"
     "\n"
     "\n Enter Choice: "
@@ -1209,8 +1241,8 @@ static char menu[] = {
 static vx_status app_run_graph_interactive(AppObj *obj)
 {
     vx_status status;
-    uint32_t done = 0;
-    char ch;
+    uint32_t done = 0, flipdone = 0;
+    char ch, flip;
     FILE *fp;
     app_perf_point_t *perf_arr[1];
     uint8_t channel_mask = (1<<obj->selectedCam);
@@ -1270,6 +1302,85 @@ static vx_status app_run_graph_interactive(AppObj *obj)
                     break;
 #endif
 #endif
+                case 'f':
+                    while(!flipdone && (status == VX_SUCCESS))
+                    {
+                        printf(flipMenu);
+                        flip = getchar();
+                        printf("\n");
+                        vx_user_data_object flip_obj;
+                        tivx_display_fliptype_t display_flip;
+                        vx_reference refs[1];
+                        flip_obj = vxCreateUserDataObject(obj->context, "tivx_display_fliptype_t", sizeof(tivx_display_fliptype_t), NULL);
+                        switch(flip)
+                        {
+                            case 'v':
+                                display_flip.flipType = FLIP_TYPE_V;
+                                if(status == VX_SUCCESS)
+                                {
+                                    status = vxCopyUserDataObject(flip_obj, 0, sizeof(tivx_display_fliptype_t), &display_flip, VX_WRITE_ONLY, VX_MEMORY_TYPE_HOST);
+                                }
+                                refs[0] = (vx_reference)flip_obj;
+                                if(status == VX_SUCCESS)
+                                {
+                                    status = tivxNodeSendCommand(obj->displayNode, 0u, TIVX_DISPLAY_SELECT_FLIP, refs, 1u);
+                                    printf("Flip Success\n");
+                                }
+                                break;
+
+                            case 'h':
+                                display_flip.flipType = FLIP_TYPE_H;
+                                if(status == VX_SUCCESS)
+                                {
+                                    status = vxCopyUserDataObject(flip_obj, 0, sizeof(tivx_display_fliptype_t), &display_flip, VX_WRITE_ONLY, VX_MEMORY_TYPE_HOST);
+                                }
+                                refs[0] = (vx_reference)flip_obj;
+                                if(status == VX_SUCCESS)
+                                {
+                                    status = tivxNodeSendCommand(obj->displayNode, 0u, TIVX_DISPLAY_SELECT_FLIP, refs, 1u);
+                                    printf("Flip Success\n");
+                                }
+                                break;
+
+                            case 'f':
+                                display_flip.flipType = FLIP_TYPE_HV;
+                                if(status == VX_SUCCESS)
+                                {
+                                    status = vxCopyUserDataObject(flip_obj, 0, sizeof(tivx_display_fliptype_t), &display_flip, VX_WRITE_ONLY, VX_MEMORY_TYPE_HOST);
+                                }
+                                refs[0] = (vx_reference)flip_obj;
+                                if(status == VX_SUCCESS)
+                                {
+                                    status = tivxNodeSendCommand(obj->displayNode, 0u, TIVX_DISPLAY_SELECT_FLIP, refs, 1u);
+                                    printf("Flip Success\n");
+                                }
+                                break;
+
+                            case 'n':
+                                display_flip.flipType = FLIP_TYPE_NONE;
+                                if(status == VX_SUCCESS)
+                                {
+                                    status = vxCopyUserDataObject(flip_obj, 0, sizeof(tivx_display_fliptype_t), &display_flip, VX_WRITE_ONLY, VX_MEMORY_TYPE_HOST);
+                                }
+                                refs[0] = (vx_reference)flip_obj;
+                                if(status == VX_SUCCESS)
+                                {
+                                    status = tivxNodeSendCommand(obj->displayNode, 0u, TIVX_DISPLAY_SELECT_FLIP, refs, 1u);
+                                    printf("Flip Success\n");
+                                }
+                                break;
+
+                            case 'x':
+                                flipdone = 1;
+                                break;
+
+                            default:
+                                printf("Unsupported Flip command %c\n", flip);
+                                break;
+                        }
+                    }
+                    flipdone = 0;
+                    break;
 
                 case 'x':
                     obj->stop_task = 1;
